* [PATCH i-g-t 1/3] tests/dmabuf: Port dmabuf tests to KUnit
2026-06-23 20:01 [PATCH i-g-t 0/3] Treat new/moved KUnit tests as such Krzysztof Niemiec
@ 2026-06-23 20:01 ` Krzysztof Niemiec
2026-06-24 14:12 ` Krzysztof Karas
2026-06-23 20:01 ` [PATCH i-g-t 2/3] tests/gpu_buddy: Update buddy allocator tests Krzysztof Niemiec
` (4 subsequent siblings)
5 siblings, 1 reply; 13+ messages in thread
From: Krzysztof Niemiec @ 2026-06-23 20:01 UTC (permalink / raw)
To: igt-dev
Cc: Andi Shyti, Janusz Krzysztofik, Kamil Konieczny, Krzysztof Karas,
Sebastian Brzezinka, Krzysztof Niemiec
The dmabuf tests have been moved out of the selftest mechanism into
KUnit in these commits in the kernel:
commit 126c50bc2fb6 ("dma-buf: Remove the old selftest")
commit 6055c9e333cf ("dma-buf: Change st-dma-fence-chain.c to use kunit")
commit 465f3934381c ("dma-buf: Change st-dma-fence-unwrap.c to use kunit")
commit 9baa35a39939 ("dma-buf: Change st-dma-fence.c to use kunit")
commit 15b9bde78bad ("dma-buf: Change st-dma-resv.c to use kunit")
Launch dmabuf tests as KUnit tests instead of selftests from IGT's side
to reflect the kernel changes.
Signed-off-by: Krzysztof Niemiec <krzysztof.niemiec@intel.com>
---
tests/dmabuf.c | 35 +++++++++++++++++++----------------
1 file changed, 19 insertions(+), 16 deletions(-)
--
2.45.2
^ permalink raw reply related [flat|nested] 13+ messages in thread* Re: [PATCH i-g-t 1/3] tests/dmabuf: Port dmabuf tests to KUnit
2026-06-23 20:01 ` [PATCH i-g-t 1/3] tests/dmabuf: Port dmabuf tests to KUnit Krzysztof Niemiec
@ 2026-06-24 14:12 ` Krzysztof Karas
0 siblings, 0 replies; 13+ messages in thread
From: Krzysztof Karas @ 2026-06-24 14:12 UTC (permalink / raw)
To: Krzysztof Niemiec
Cc: igt-dev, Andi Shyti, Janusz Krzysztofik, Kamil Konieczny,
Sebastian Brzezinka
Hi Krzysztof,
On 2026-06-23 at 22:01:50 +0200, Krzysztof Niemiec wrote:
> The dmabuf tests have been moved out of the selftest mechanism into
> KUnit in these commits in the kernel:
>
> commit 126c50bc2fb6 ("dma-buf: Remove the old selftest")
> commit 6055c9e333cf ("dma-buf: Change st-dma-fence-chain.c to use kunit")
> commit 465f3934381c ("dma-buf: Change st-dma-fence-unwrap.c to use kunit")
> commit 9baa35a39939 ("dma-buf: Change st-dma-fence.c to use kunit")
> commit 15b9bde78bad ("dma-buf: Change st-dma-resv.c to use kunit")
>
> Launch dmabuf tests as KUnit tests instead of selftests from IGT's side
> to reflect the kernel changes.
>
> Signed-off-by: Krzysztof Niemiec <krzysztof.niemiec@intel.com>
> ---
> tests/dmabuf.c | 35 +++++++++++++++++++----------------
> 1 file changed, 19 insertions(+), 16 deletions(-)
The change looks good:
Reviewed-by: Krzysztof Karas <krzysztof.karas@intel.com>
--
Best Regards,
Krzysztof
^ permalink raw reply [flat|nested] 13+ messages in thread
* [PATCH i-g-t 2/3] tests/gpu_buddy: Update buddy allocator tests
2026-06-23 20:01 [PATCH i-g-t 0/3] Treat new/moved KUnit tests as such Krzysztof Niemiec
2026-06-23 20:01 ` [PATCH i-g-t 1/3] tests/dmabuf: Port dmabuf tests to KUnit Krzysztof Niemiec
@ 2026-06-23 20:01 ` Krzysztof Niemiec
2026-06-24 9:54 ` Sebastian Brzezinka
` (2 more replies)
2026-06-23 20:01 ` [PATCH i-g-t 3/3] tests/intel-ci: Remove dmabuf tests from i915 fast feedback Krzysztof Niemiec
` (3 subsequent siblings)
5 siblings, 3 replies; 13+ messages in thread
From: Krzysztof Niemiec @ 2026-06-23 20:01 UTC (permalink / raw)
To: igt-dev
Cc: Andi Shyti, Janusz Krzysztofik, Kamil Konieczny, Krzysztof Karas,
Sebastian Brzezinka, Krzysztof Niemiec
The DRM buddy allocator has been moved one level up, and is now renamed
to just the GPU buddy allocator. This means that the .ko object used to
run the KUnit test has been renamed, so IGT tries to run a test that
doesn't exist anymore.
Rename the drm_buddy.c file to gpu_buddy.c to reflect the kernel change,
and update the igt_kunit() call to invoke the proper tests. Also update
tests/meson.build to prevent the build system from trying to build
drm_buddy, and make it build gpu_buddy in its stead.
Signed-off-by: Krzysztof Niemiec <krzysztof.niemiec@intel.com>
---
tests/{drm_buddy.c => gpu_buddy.c} | 4 ++--
tests/meson.build | 2 +-
2 files changed, 3 insertions(+), 3 deletions(-)
rename tests/{drm_buddy.c => gpu_buddy.c} (51%)
diff --git a/tests/drm_buddy.c b/tests/gpu_buddy.c
similarity index 51%
rename from tests/drm_buddy.c
rename to tests/gpu_buddy.c
index dbc7c957d..8683b5af0 100644
--- a/tests/drm_buddy.c
+++ b/tests/gpu_buddy.c
@@ -6,9 +6,9 @@
#include "igt.h"
#include "igt_kmod.h"
-IGT_TEST_DESCRIPTION("Basic sanity check of DRM's buddy allocator (struct drm_buddy)");
+IGT_TEST_DESCRIPTION("Basic sanity check of the GPU buddy allocator (struct gpu_buddy)");
int igt_main()
{
- igt_kunit("drm_buddy_test", NULL, NULL);
+ igt_kunit("gpu_buddy_tests", NULL, NULL);
}
diff --git a/tests/meson.build b/tests/meson.build
index 4c1a39e9e..0d9008bbd 100644
--- a/tests/meson.build
+++ b/tests/meson.build
@@ -12,11 +12,11 @@ test_progs = [
'dmabuf_sync_file',
'device_reset',
'dumb_buffer',
- 'drm_buddy',
'drm_mm',
'drm_read',
'drm_virtgpu',
'fbdev',
+ 'gpu_buddy',
'kms_3d',
'kms_addfb_basic',
'kms_async_flips',
--
2.45.2
^ permalink raw reply related [flat|nested] 13+ messages in thread* Re: [PATCH i-g-t 2/3] tests/gpu_buddy: Update buddy allocator tests
2026-06-23 20:01 ` [PATCH i-g-t 2/3] tests/gpu_buddy: Update buddy allocator tests Krzysztof Niemiec
@ 2026-06-24 9:54 ` Sebastian Brzezinka
2026-06-24 12:08 ` Kamil Konieczny
2026-06-24 14:15 ` Krzysztof Karas
2 siblings, 0 replies; 13+ messages in thread
From: Sebastian Brzezinka @ 2026-06-24 9:54 UTC (permalink / raw)
To: Krzysztof Niemiec, igt-dev
Cc: Andi Shyti, Janusz Krzysztofik, Kamil Konieczny, Krzysztof Karas,
Sebastian Brzezinka
Hi Krzysztof,
On Tue Jun 23, 2026 at 10:01 PM CEST, Krzysztof Niemiec wrote:
> The DRM buddy allocator has been moved one level up, and is now renamed
> to just the GPU buddy allocator. This means that the .ko object used to
> run the KUnit test has been renamed, so IGT tries to run a test that
> doesn't exist anymore.
>
> Rename the drm_buddy.c file to gpu_buddy.c to reflect the kernel change,
> and update the igt_kunit() call to invoke the proper tests. Also update
> tests/meson.build to prevent the build system from trying to build
> drm_buddy, and make it build gpu_buddy in its stead.
>
> Signed-off-by: Krzysztof Niemiec <krzysztof.niemiec@intel.com>
> ---
> tests/{drm_buddy.c => gpu_buddy.c} | 4 ++--
> tests/meson.build | 2 +-
> 2 files changed, 3 insertions(+), 3 deletions(-)
> rename tests/{drm_buddy.c => gpu_buddy.c} (51%)
>
> diff --git a/tests/drm_buddy.c b/tests/gpu_buddy.c
> similarity index 51%
> rename from tests/drm_buddy.c
> rename to tests/gpu_buddy.c
> index dbc7c957d..8683b5af0 100644
> --- a/tests/drm_buddy.c
> +++ b/tests/gpu_buddy.c
> @@ -6,9 +6,9 @@
> #include "igt.h"
> #include "igt_kmod.h"
>
> -IGT_TEST_DESCRIPTION("Basic sanity check of DRM's buddy allocator (struct drm_buddy)");
> +IGT_TEST_DESCRIPTION("Basic sanity check of the GPU buddy allocator (struct gpu_buddy)");
>
> int igt_main()
> {
> - igt_kunit("drm_buddy_test", NULL, NULL);
> + igt_kunit("gpu_buddy_tests", NULL, NULL);
For some reason, I checked it, and igt_kunit uses strstr() to match _test,
so the _tests might be ok. Still, I would prefer the singular form.
But if it works, I'm fine with this.
Reviewed-by: Sebastian Brzezinka <sebastian.brzezinka@intel.com>
--
Best regards,
Sebastian
^ permalink raw reply [flat|nested] 13+ messages in thread* Re: [PATCH i-g-t 2/3] tests/gpu_buddy: Update buddy allocator tests
2026-06-23 20:01 ` [PATCH i-g-t 2/3] tests/gpu_buddy: Update buddy allocator tests Krzysztof Niemiec
2026-06-24 9:54 ` Sebastian Brzezinka
@ 2026-06-24 12:08 ` Kamil Konieczny
2026-06-24 14:15 ` Krzysztof Karas
2 siblings, 0 replies; 13+ messages in thread
From: Kamil Konieczny @ 2026-06-24 12:08 UTC (permalink / raw)
To: Krzysztof Niemiec
Cc: igt-dev, Andi Shyti, Janusz Krzysztofik, Krzysztof Karas,
Sebastian Brzezinka
Hi Krzysztof,
On 2026-06-23 at 22:01:51 +0200, Krzysztof Niemiec wrote:
imho subject could be improved, like
[PATCH i-g-t 2/3] tests/gpu_buddy: Rename KUnit buddy allocator test
or am I missing something?
> The DRM buddy allocator has been moved one level up, and is now renamed
> to just the GPU buddy allocator. This means that the .ko object used to
> run the KUnit test has been renamed, so IGT tries to run a test that
> doesn't exist anymore.
>
> Rename the drm_buddy.c file to gpu_buddy.c to reflect the kernel change,
> and update the igt_kunit() call to invoke the proper tests. Also update
> tests/meson.build to prevent the build system from trying to build
You do not need to describe change in build meson, it is natural
to change it when renaming test file.
Regards,
Kamil
> drm_buddy, and make it build gpu_buddy in its stead.
>
> Signed-off-by: Krzysztof Niemiec <krzysztof.niemiec@intel.com>
> ---
> tests/{drm_buddy.c => gpu_buddy.c} | 4 ++--
> tests/meson.build | 2 +-
> 2 files changed, 3 insertions(+), 3 deletions(-)
> rename tests/{drm_buddy.c => gpu_buddy.c} (51%)
>
> diff --git a/tests/drm_buddy.c b/tests/gpu_buddy.c
> similarity index 51%
> rename from tests/drm_buddy.c
> rename to tests/gpu_buddy.c
> index dbc7c957d..8683b5af0 100644
> --- a/tests/drm_buddy.c
> +++ b/tests/gpu_buddy.c
> @@ -6,9 +6,9 @@
> #include "igt.h"
> #include "igt_kmod.h"
>
> -IGT_TEST_DESCRIPTION("Basic sanity check of DRM's buddy allocator (struct drm_buddy)");
> +IGT_TEST_DESCRIPTION("Basic sanity check of the GPU buddy allocator (struct gpu_buddy)");
>
> int igt_main()
> {
> - igt_kunit("drm_buddy_test", NULL, NULL);
> + igt_kunit("gpu_buddy_tests", NULL, NULL);
> }
> diff --git a/tests/meson.build b/tests/meson.build
> index 4c1a39e9e..0d9008bbd 100644
> --- a/tests/meson.build
> +++ b/tests/meson.build
> @@ -12,11 +12,11 @@ test_progs = [
> 'dmabuf_sync_file',
> 'device_reset',
> 'dumb_buffer',
> - 'drm_buddy',
> 'drm_mm',
> 'drm_read',
> 'drm_virtgpu',
> 'fbdev',
> + 'gpu_buddy',
> 'kms_3d',
> 'kms_addfb_basic',
> 'kms_async_flips',
> --
> 2.45.2
>
^ permalink raw reply [flat|nested] 13+ messages in thread* Re: [PATCH i-g-t 2/3] tests/gpu_buddy: Update buddy allocator tests
2026-06-23 20:01 ` [PATCH i-g-t 2/3] tests/gpu_buddy: Update buddy allocator tests Krzysztof Niemiec
2026-06-24 9:54 ` Sebastian Brzezinka
2026-06-24 12:08 ` Kamil Konieczny
@ 2026-06-24 14:15 ` Krzysztof Karas
2 siblings, 0 replies; 13+ messages in thread
From: Krzysztof Karas @ 2026-06-24 14:15 UTC (permalink / raw)
To: Krzysztof Niemiec
Cc: igt-dev, Andi Shyti, Janusz Krzysztofik, Kamil Konieczny,
Sebastian Brzezinka
Hi Krzysztof,
On 2026-06-23 at 22:01:51 +0200, Krzysztof Niemiec wrote:
> The DRM buddy allocator has been moved one level up, and is now renamed
> to just the GPU buddy allocator. This means that the .ko object used to
> run the KUnit test has been renamed, so IGT tries to run a test that
> doesn't exist anymore.
>
> Rename the drm_buddy.c file to gpu_buddy.c to reflect the kernel change,
> and update the igt_kunit() call to invoke the proper tests. Also update
> tests/meson.build to prevent the build system from trying to build
> drm_buddy, and make it build gpu_buddy in its stead.
>
> Signed-off-by: Krzysztof Niemiec <krzysztof.niemiec@intel.com>
> ---
Reviewed-by: Krzysztof Karas <krzysztof.karas@intel.com>
--
Best Regards,
Krzysztof
^ permalink raw reply [flat|nested] 13+ messages in thread
* [PATCH i-g-t 3/3] tests/intel-ci: Remove dmabuf tests from i915 fast feedback
2026-06-23 20:01 [PATCH i-g-t 0/3] Treat new/moved KUnit tests as such Krzysztof Niemiec
2026-06-23 20:01 ` [PATCH i-g-t 1/3] tests/dmabuf: Port dmabuf tests to KUnit Krzysztof Niemiec
2026-06-23 20:01 ` [PATCH i-g-t 2/3] tests/gpu_buddy: Update buddy allocator tests Krzysztof Niemiec
@ 2026-06-23 20:01 ` Krzysztof Niemiec
2026-06-24 11:50 ` Kamil Konieczny
2026-06-24 14:17 ` Krzysztof Karas
2026-06-23 20:54 ` ✓ Xe.CI.BAT: success for Treat new/moved KUnit tests as such Patchwork
` (2 subsequent siblings)
5 siblings, 2 replies; 13+ messages in thread
From: Krzysztof Niemiec @ 2026-06-23 20:01 UTC (permalink / raw)
To: igt-dev
Cc: Andi Shyti, Janusz Krzysztofik, Kamil Konieczny, Krzysztof Karas,
Sebastian Brzezinka, Krzysztof Niemiec
Intel CI runs KUnit tests separately from regular tests. Remove the
dmabuf tests from the i915 fast feedback testlist, as they are now
KUnit tests, instead of selftests.
Signed-off-by: Krzysztof Niemiec <krzysztof.niemiec@intel.com>
---
tests/intel-ci/i915.fast-feedback.testlist | 1 -
1 file changed, 1 deletion(-)
diff --git a/tests/intel-ci/i915.fast-feedback.testlist b/tests/intel-ci/i915.fast-feedback.testlist
index 2799bbaa5..5b33f29e4 100644
--- a/tests/intel-ci/i915.fast-feedback.testlist
+++ b/tests/intel-ci/i915.fast-feedback.testlist
@@ -168,4 +168,3 @@ igt@i915_pm_rpm@module-reload
# Kernel selftests
igt@i915_selftest@live
-igt@dmabuf@all-tests
diff --git a/tests/dmabuf.c b/tests/dmabuf.c
index 322981473..1baefb299 100644
--- a/tests/dmabuf.c
+++ b/tests/dmabuf.c
@@ -25,7 +25,7 @@
#include "igt_kmod.h"
/**
* TEST: dmabuf
* Description: Kernel selftests for the dmabuf API
* Category: Core
* Mega feature: General Core features
* Functionality: drm_mm
@@ -33,14 +33,16 @@
* Feature: mapping, prime
* Test category: GEM_Legacy
*
- * SUBTEST: all-tests
+ * SUBTEST: dma-buf-resv
*
- * SUBTEST: all-tests@dma_fence
+ * SUBTEST: dma-buf-fence
*
- * SUBTEST: all-tests@sanitycheck
+ * SUBTEST: dma-buf-fence-unwrap
+ *
+ * SUBTEST: dma-buf-fence-chain
*/
-IGT_TEST_DESCRIPTION("Kernel selftests for the dmabuf API");
+IGT_TEST_DESCRIPTION("KUnit tests for the dmabuf API");
static unsigned int bogomips(void)
{
@@ -76,23 +78,24 @@ static unsigned int bogomips(void)
return igt_debug_on(!bogomips) ? UINT_MAX : ret;
}
-static int wrapper(const char *dynamic_name,
- struct igt_ktest *tst,
- struct igt_kselftest_list *tl)
+int igt_main()
{
+ igt_kunit("dmabuf_kunit", "dma-buf-resv", NULL);
+ igt_kunit("dmabuf_kunit", "dma-buf-fence", NULL);
+
/*
* Test case wait-backward of dma_fence_chain selftest can trigger soft
* lockups on slow machines. Since that slowness is not recognized as
* a bug on the kernel side, the issue is not going to be fixed. Based
- * on analysis of CI results, skip that selftest on machines slower than
+ * on analysis of CI results, skip that test on machines slower than
* 25000 BogoMIPS to avoid ever returning CI reports on that failure.
*/
- igt_skip_on(!strcmp(dynamic_name, "dma_fence_chain") && bogomips() < 25000);
- return igt_kselftest_execute(tst, tl, NULL, NULL);
-}
+ if (bogomips() >= 25000)
+ igt_kunit("dmabuf_kunit", "dma-buf-fence-chain", NULL);
+ else
+ igt_subtest("dma-buf-fence-chain")
+ igt_skip("BogoMips < 25000 - test is not supported\n");
-int igt_main()
-{
- igt_kselftests("dmabuf_selftests", NULL, NULL, NULL, wrapper);
+ igt_kunit("dmabuf_kunit", "dma-buf-fence-unwrap", NULL);
}
@@ -25,7 +25,7 @@
/**
* TEST: dmabuf
- * Description: Kernel selftests for the dmabuf API
+ * Description: KUnit tests for the dmabuf API
* Category: Core
* Mega feature: General Core features
@@ -76,23 +78,24 @@ static unsigned int bogomips(void)
/*
- * Test case wait-backward of dma_fence_chain selftest can trigger soft
+ * Test case wait-backward of dma-buf-fence-chain test can trigger soft
* lockups on slow machines. Since that slowness is not recognized as
* a bug on the kernel side, the issue is not going to be fixed. Based
--
2.45.2
^ permalink raw reply related [flat|nested] 13+ messages in thread* Re: [PATCH i-g-t 3/3] tests/intel-ci: Remove dmabuf tests from i915 fast feedback
2026-06-23 20:01 ` [PATCH i-g-t 3/3] tests/intel-ci: Remove dmabuf tests from i915 fast feedback Krzysztof Niemiec
@ 2026-06-24 11:50 ` Kamil Konieczny
2026-06-24 14:17 ` Krzysztof Karas
1 sibling, 0 replies; 13+ messages in thread
From: Kamil Konieczny @ 2026-06-24 11:50 UTC (permalink / raw)
To: Krzysztof Niemiec
Cc: igt-dev, Andi Shyti, Janusz Krzysztofik, Krzysztof Karas,
Sebastian Brzezinka
Hi Krzysztof,
On 2026-06-23 at 22:01:52 +0200, Krzysztof Niemiec wrote:
> Intel CI runs KUnit tests separately from regular tests. Remove the
> dmabuf tests from the i915 fast feedback testlist, as they are now
> KUnit tests, instead of selftests.
>
> Signed-off-by: Krzysztof Niemiec <krzysztof.niemiec@intel.com>
> ---
> tests/intel-ci/i915.fast-feedback.testlist | 1 -
> 1 file changed, 1 deletion(-)
>
> diff --git a/tests/intel-ci/i915.fast-feedback.testlist b/tests/intel-ci/i915.fast-feedback.testlist
> index 2799bbaa5..5b33f29e4 100644
> --- a/tests/intel-ci/i915.fast-feedback.testlist
> +++ b/tests/intel-ci/i915.fast-feedback.testlist
> @@ -168,4 +168,3 @@ igt@i915_pm_rpm@module-reload
>
> # Kernel selftests
> igt@i915_selftest@live
> -igt@dmabuf@all-tests
This should be first patch in a series.
LGTM
Reviewed-by: Kamil Konieczny <kamil.konieczny@linux.intel.com>
Regards,
Kamil
> --
> 2.45.2
>
^ permalink raw reply [flat|nested] 13+ messages in thread
* Re: [PATCH i-g-t 3/3] tests/intel-ci: Remove dmabuf tests from i915 fast feedback
2026-06-23 20:01 ` [PATCH i-g-t 3/3] tests/intel-ci: Remove dmabuf tests from i915 fast feedback Krzysztof Niemiec
2026-06-24 11:50 ` Kamil Konieczny
@ 2026-06-24 14:17 ` Krzysztof Karas
1 sibling, 0 replies; 13+ messages in thread
From: Krzysztof Karas @ 2026-06-24 14:17 UTC (permalink / raw)
To: Krzysztof Niemiec
Cc: igt-dev, Andi Shyti, Janusz Krzysztofik, Kamil Konieczny,
Sebastian Brzezinka
Hi Krzysztof,
On 2026-06-23 at 22:01:52 +0200, Krzysztof Niemiec wrote:
> Intel CI runs KUnit tests separately from regular tests. Remove the
> dmabuf tests from the i915 fast feedback testlist, as they are now
> KUnit tests, instead of selftests.
>
> Signed-off-by: Krzysztof Niemiec <krzysztof.niemiec@intel.com>
> ---
> tests/intel-ci/i915.fast-feedback.testlist | 1 -
> 1 file changed, 1 deletion(-)
>
> diff --git a/tests/intel-ci/i915.fast-feedback.testlist b/tests/intel-ci/i915.fast-feedback.testlist
> index 2799bbaa5..5b33f29e4 100644
> --- a/tests/intel-ci/i915.fast-feedback.testlist
> +++ b/tests/intel-ci/i915.fast-feedback.testlist
> @@ -168,4 +168,3 @@ igt@i915_pm_rpm@module-reload
>
> # Kernel selftests
> igt@i915_selftest@live
> -igt@dmabuf@all-tests
> --
> 2.45.2
>
Reviewed-by: Krzysztof Karas <krzysztof.karas@intel.com>
--
Best Regards,
Krzysztof
^ permalink raw reply [flat|nested] 13+ messages in thread
* ✓ Xe.CI.BAT: success for Treat new/moved KUnit tests as such
2026-06-23 20:01 [PATCH i-g-t 0/3] Treat new/moved KUnit tests as such Krzysztof Niemiec
` (2 preceding siblings ...)
2026-06-23 20:01 ` [PATCH i-g-t 3/3] tests/intel-ci: Remove dmabuf tests from i915 fast feedback Krzysztof Niemiec
@ 2026-06-23 20:54 ` Patchwork
2026-06-23 21:09 ` ✗ i915.CI.BAT: failure " Patchwork
2026-06-24 3:22 ` ✗ Xe.CI.FULL: " Patchwork
5 siblings, 0 replies; 13+ messages in thread
From: Patchwork @ 2026-06-23 20:54 UTC (permalink / raw)
To: Krzysztof Niemiec; +Cc: igt-dev
[-- Attachment #1: Type: text/plain, Size: 1055 bytes --]
== Series Details ==
Series: Treat new/moved KUnit tests as such
URL : https://patchwork.freedesktop.org/series/169049/
State : success
== Summary ==
CI Bug Log - changes from XEIGT_8981_BAT -> XEIGTPW_15435_BAT
====================================================
Summary
-------
**SUCCESS**
No regressions found.
Participating hosts (12 -> 11)
------------------------------
Missing (1): bat-bmg-vm
Changes
-------
No changes found
Build changes
-------------
* IGT: IGT_8981 -> IGTPW_15435
* Linux: xe-5290-60326b17f877e12846167bf8ef83680b9875218a -> xe-5291-e2a6e04d045a56c6dc61e1eb9e2a6d7cf86512cd
IGTPW_15435: 15435
IGT_8981: 28416da6681a1afa167bdd73cdc934cb36d13133 @ https://gitlab.freedesktop.org/drm/igt-gpu-tools.git
xe-5290-60326b17f877e12846167bf8ef83680b9875218a: 60326b17f877e12846167bf8ef83680b9875218a
xe-5291-e2a6e04d045a56c6dc61e1eb9e2a6d7cf86512cd: e2a6e04d045a56c6dc61e1eb9e2a6d7cf86512cd
== Logs ==
For more details see: https://intel-gfx-ci.01.org/tree/intel-xe/IGTPW_15435/index.html
[-- Attachment #2: Type: text/html, Size: 1614 bytes --]
^ permalink raw reply [flat|nested] 13+ messages in thread* ✗ i915.CI.BAT: failure for Treat new/moved KUnit tests as such
2026-06-23 20:01 [PATCH i-g-t 0/3] Treat new/moved KUnit tests as such Krzysztof Niemiec
` (3 preceding siblings ...)
2026-06-23 20:54 ` ✓ Xe.CI.BAT: success for Treat new/moved KUnit tests as such Patchwork
@ 2026-06-23 21:09 ` Patchwork
2026-06-24 3:22 ` ✗ Xe.CI.FULL: " Patchwork
5 siblings, 0 replies; 13+ messages in thread
From: Patchwork @ 2026-06-23 21:09 UTC (permalink / raw)
To: Krzysztof Niemiec; +Cc: igt-dev
[-- Attachment #1: Type: text/plain, Size: 8985 bytes --]
== Series Details ==
Series: Treat new/moved KUnit tests as such
URL : https://patchwork.freedesktop.org/series/169049/
State : failure
== Summary ==
CI Bug Log - changes from IGT_8981 -> IGTPW_15435
====================================================
Summary
-------
**FAILURE**
Serious unknown changes coming with IGTPW_15435 absolutely need to be
verified manually.
If you think the reported changes have nothing to do with the changes
introduced in IGTPW_15435, please notify your bug team (I915-ci-infra@lists.freedesktop.org) to allow them
to document this new failure mode, which will reduce false positives in CI.
External URL: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_15435/index.html
Participating hosts (41 -> 40)
------------------------------
Additional (1): bat-arlh-2
Missing (2): bat-dg2-13 fi-snb-2520m
Possible new issues
-------------------
Here are the unknown changes that may have been introduced in IGTPW_15435:
### IGT changes ###
#### Possible regressions ####
* igt@i915_selftest@live:
- fi-hsw-4770: [PASS][1] -> [INCOMPLETE][2]
[1]: https://intel-gfx-ci.01.org/tree/drm-tip/IGT_8981/fi-hsw-4770/igt@i915_selftest@live.html
[2]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_15435/fi-hsw-4770/igt@i915_selftest@live.html
Known issues
------------
Here are the changes found in IGTPW_15435 that come from known issues:
### IGT changes ###
#### Issues hit ####
* igt@fbdev@eof:
- bat-arlh-2: NOTRUN -> [SKIP][3] ([i915#11345] / [i915#11346]) +3 other tests skip
[3]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_15435/bat-arlh-2/igt@fbdev@eof.html
* igt@fbdev@info:
- bat-arlh-2: NOTRUN -> [SKIP][4] ([i915#11346] / [i915#1849])
[4]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_15435/bat-arlh-2/igt@fbdev@info.html
* igt@gem_lmem_swapping@basic:
- bat-arlh-2: NOTRUN -> [SKIP][5] ([i915#10213] / [i915#11346] / [i915#11671]) +3 other tests skip
[5]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_15435/bat-arlh-2/igt@gem_lmem_swapping@basic.html
* igt@gem_mmap@basic:
- bat-arlh-2: NOTRUN -> [SKIP][6] ([i915#11343] / [i915#11346])
[6]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_15435/bat-arlh-2/igt@gem_mmap@basic.html
* igt@gem_render_tiled_blits@basic:
- bat-arlh-2: NOTRUN -> [SKIP][7] ([i915#10197] / [i915#10211] / [i915#11346] / [i915#11725] / [i915#4079])
[7]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_15435/bat-arlh-2/igt@gem_render_tiled_blits@basic.html
* igt@gem_tiled_blits@basic:
- bat-arlh-2: NOTRUN -> [SKIP][8] ([i915#11346] / [i915#12637]) +4 other tests skip
[8]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_15435/bat-arlh-2/igt@gem_tiled_blits@basic.html
* igt@gem_tiled_pread_basic@basic:
- bat-arlh-2: NOTRUN -> [SKIP][9] ([i915#11346] / [i915#15657])
[9]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_15435/bat-arlh-2/igt@gem_tiled_pread_basic@basic.html
* igt@i915_pm_rps@basic-api:
- bat-arlh-2: NOTRUN -> [SKIP][10] ([i915#10209] / [i915#11346] / [i915#11681])
[10]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_15435/bat-arlh-2/igt@i915_pm_rps@basic-api.html
* igt@i915_selftest@live@hangcheck:
- fi-hsw-4770: [PASS][11] -> [INCOMPLETE][12] ([i915#16139])
[11]: https://intel-gfx-ci.01.org/tree/drm-tip/IGT_8981/fi-hsw-4770/igt@i915_selftest@live@hangcheck.html
[12]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_15435/fi-hsw-4770/igt@i915_selftest@live@hangcheck.html
* igt@intel_hwmon@hwmon-read:
- bat-arlh-2: NOTRUN -> [SKIP][13] ([i915#11346] / [i915#11680] / [i915#7707]) +1 other test skip
[13]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_15435/bat-arlh-2/igt@intel_hwmon@hwmon-read.html
* igt@kms_addfb_basic@addfb25-y-tiled-small-legacy:
- bat-arlh-2: NOTRUN -> [SKIP][14] ([i915#10200] / [i915#11346] / [i915#11666] / [i915#12203])
[14]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_15435/bat-arlh-2/igt@kms_addfb_basic@addfb25-y-tiled-small-legacy.html
* igt@kms_addfb_basic@basic-x-tiled-legacy:
- bat-arlh-2: NOTRUN -> [SKIP][15] ([i915#10200] / [i915#11346] / [i915#11666]) +8 other tests skip
[15]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_15435/bat-arlh-2/igt@kms_addfb_basic@basic-x-tiled-legacy.html
* igt@kms_force_connector_basic@force-connector-state:
- bat-arlh-2: NOTRUN -> [SKIP][16] ([i915#11346]) +5 other tests skip
[16]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_15435/bat-arlh-2/igt@kms_force_connector_basic@force-connector-state.html
* igt@kms_pipe_crc_basic@nonblocking-crc:
- bat-arlh-2: NOTRUN -> [SKIP][17] ([i915#11190] / [i915#11346]) +16 other tests skip
[17]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_15435/bat-arlh-2/igt@kms_pipe_crc_basic@nonblocking-crc.html
* igt@kms_psr@psr-primary-page-flip:
- bat-arlh-2: NOTRUN -> [SKIP][18] ([i915#11346] / [i915#15855]) +9 other tests skip
[18]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_15435/bat-arlh-2/igt@kms_psr@psr-primary-page-flip.html
* igt@kms_setmode@basic-clone-single-crtc:
- bat-arlh-2: NOTRUN -> [SKIP][19] ([i915#10208] / [i915#11346] / [i915#8809])
[19]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_15435/bat-arlh-2/igt@kms_setmode@basic-clone-single-crtc.html
* igt@prime_vgem@basic-fence-read:
- bat-arlh-2: NOTRUN -> [SKIP][20] ([i915#10212] / [i915#11346] / [i915#11726])
[20]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_15435/bat-arlh-2/igt@prime_vgem@basic-fence-read.html
* igt@prime_vgem@basic-read:
- bat-arlh-2: NOTRUN -> [SKIP][21] ([i915#10214] / [i915#11346] / [i915#11726])
[21]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_15435/bat-arlh-2/igt@prime_vgem@basic-read.html
* igt@prime_vgem@basic-write:
- bat-arlh-2: NOTRUN -> [SKIP][22] ([i915#10216] / [i915#11346] / [i915#11723])
[22]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_15435/bat-arlh-2/igt@prime_vgem@basic-write.html
[i915#10197]: https://gitlab.freedesktop.org/drm/i915/kernel/-/issues/10197
[i915#10200]: https://gitlab.freedesktop.org/drm/i915/kernel/-/issues/10200
[i915#10208]: https://gitlab.freedesktop.org/drm/i915/kernel/-/issues/10208
[i915#10209]: https://gitlab.freedesktop.org/drm/i915/kernel/-/issues/10209
[i915#10211]: https://gitlab.freedesktop.org/drm/i915/kernel/-/issues/10211
[i915#10212]: https://gitlab.freedesktop.org/drm/i915/kernel/-/issues/10212
[i915#10213]: https://gitlab.freedesktop.org/drm/i915/kernel/-/issues/10213
[i915#10214]: https://gitlab.freedesktop.org/drm/i915/kernel/-/issues/10214
[i915#10216]: https://gitlab.freedesktop.org/drm/i915/kernel/-/issues/10216
[i915#11190]: https://gitlab.freedesktop.org/drm/i915/kernel/-/issues/11190
[i915#11343]: https://gitlab.freedesktop.org/drm/i915/kernel/-/issues/11343
[i915#11345]: https://gitlab.freedesktop.org/drm/i915/kernel/-/issues/11345
[i915#11346]: https://gitlab.freedesktop.org/drm/i915/kernel/-/issues/11346
[i915#11666]: https://gitlab.freedesktop.org/drm/i915/kernel/-/issues/11666
[i915#11671]: https://gitlab.freedesktop.org/drm/i915/kernel/-/issues/11671
[i915#11680]: https://gitlab.freedesktop.org/drm/i915/kernel/-/issues/11680
[i915#11681]: https://gitlab.freedesktop.org/drm/i915/kernel/-/issues/11681
[i915#11723]: https://gitlab.freedesktop.org/drm/i915/kernel/-/issues/11723
[i915#11725]: https://gitlab.freedesktop.org/drm/i915/kernel/-/issues/11725
[i915#11726]: https://gitlab.freedesktop.org/drm/i915/kernel/-/issues/11726
[i915#12203]: https://gitlab.freedesktop.org/drm/i915/kernel/-/issues/12203
[i915#12637]: https://gitlab.freedesktop.org/drm/i915/kernel/-/issues/12637
[i915#15657]: https://gitlab.freedesktop.org/drm/i915/kernel/-/issues/15657
[i915#15855]: https://gitlab.freedesktop.org/drm/i915/kernel/-/issues/15855
[i915#16139]: https://gitlab.freedesktop.org/drm/i915/kernel/-/issues/16139
[i915#1849]: https://gitlab.freedesktop.org/drm/i915/kernel/-/issues/1849
[i915#4079]: https://gitlab.freedesktop.org/drm/i915/kernel/-/issues/4079
[i915#7707]: https://gitlab.freedesktop.org/drm/i915/kernel/-/issues/7707
[i915#8809]: https://gitlab.freedesktop.org/drm/i915/kernel/-/issues/8809
Build changes
-------------
* CI: CI-20190529 -> None
* IGT: IGT_8981 -> IGTPW_15435
* Linux: CI_DRM_18709 -> CI_DRM_18711
CI-20190529: 20190529
CI_DRM_18709: 60326b17f877e12846167bf8ef83680b9875218a @ git://anongit.freedesktop.org/gfx-ci/linux
CI_DRM_18711: e2a6e04d045a56c6dc61e1eb9e2a6d7cf86512cd @ git://anongit.freedesktop.org/gfx-ci/linux
IGTPW_15435: 15435
IGT_8981: 28416da6681a1afa167bdd73cdc934cb36d13133 @ https://gitlab.freedesktop.org/drm/igt-gpu-tools.git
== Logs ==
For more details see: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_15435/index.html
[-- Attachment #2: Type: text/html, Size: 11545 bytes --]
^ permalink raw reply [flat|nested] 13+ messages in thread* ✗ Xe.CI.FULL: failure for Treat new/moved KUnit tests as such
2026-06-23 20:01 [PATCH i-g-t 0/3] Treat new/moved KUnit tests as such Krzysztof Niemiec
` (4 preceding siblings ...)
2026-06-23 21:09 ` ✗ i915.CI.BAT: failure " Patchwork
@ 2026-06-24 3:22 ` Patchwork
5 siblings, 0 replies; 13+ messages in thread
From: Patchwork @ 2026-06-24 3:22 UTC (permalink / raw)
To: Krzysztof Niemiec; +Cc: igt-dev
[-- Attachment #1: Type: text/plain, Size: 16590 bytes --]
== Series Details ==
Series: Treat new/moved KUnit tests as such
URL : https://patchwork.freedesktop.org/series/169049/
State : failure
== Summary ==
CI Bug Log - changes from XEIGT_8981_FULL -> XEIGTPW_15435_FULL
====================================================
Summary
-------
**FAILURE**
Serious unknown changes coming with XEIGTPW_15435_FULL absolutely need to be
verified manually.
If you think the reported changes have nothing to do with the changes
introduced in XEIGTPW_15435_FULL, please notify your bug team (I915-ci-infra@lists.freedesktop.org) to allow them
to document this new failure mode, which will reduce false positives in CI.
Participating hosts (2 -> 2)
------------------------------
No changes in participating hosts
Possible new issues
-------------------
Here are the unknown changes that may have been introduced in XEIGTPW_15435_FULL:
### IGT changes ###
#### Possible regressions ####
* {igt@gpu_buddy@gpu_buddy} (NEW):
- shard-bmg: NOTRUN -> [SKIP][1] +1 other test skip
[1]: https://intel-gfx-ci.01.org/tree/intel-xe/IGTPW_15435/shard-bmg-4/igt@gpu_buddy@gpu_buddy.html
- shard-lnl: NOTRUN -> [SKIP][2]
[2]: https://intel-gfx-ci.01.org/tree/intel-xe/IGTPW_15435/shard-lnl-3/igt@gpu_buddy@gpu_buddy.html
New tests
---------
New tests have been introduced between XEIGT_8981_FULL and XEIGTPW_15435_FULL:
### New IGT tests (1) ###
* igt@gpu_buddy@gpu_buddy:
- Statuses : 2 skip(s)
- Exec time: [0.00] s
Known issues
------------
Here are the changes found in XEIGTPW_15435_FULL that come from known issues:
### IGT changes ###
#### Issues hit ####
* igt@kms_big_fb@y-tiled-max-hw-stride-64bpp-rotate-180-hflip:
- shard-bmg: NOTRUN -> [SKIP][3] ([Intel XE#1124]) +1 other test skip
[3]: https://intel-gfx-ci.01.org/tree/intel-xe/IGTPW_15435/shard-bmg-1/igt@kms_big_fb@y-tiled-max-hw-stride-64bpp-rotate-180-hflip.html
* igt@kms_bw@linear-tiling-3-displays-target-3840x2160p:
- shard-bmg: NOTRUN -> [SKIP][4] ([Intel XE#367])
[4]: https://intel-gfx-ci.01.org/tree/intel-xe/IGTPW_15435/shard-bmg-7/igt@kms_bw@linear-tiling-3-displays-target-3840x2160p.html
* igt@kms_ccs@ccs-on-another-bo-y-tiled-gen12-rc-ccs:
- shard-bmg: NOTRUN -> [SKIP][5] ([Intel XE#2887]) +1 other test skip
[5]: https://intel-gfx-ci.01.org/tree/intel-xe/IGTPW_15435/shard-bmg-8/igt@kms_ccs@ccs-on-another-bo-y-tiled-gen12-rc-ccs.html
* igt@kms_ccs@crc-primary-suspend-y-tiled-gen12-mc-ccs:
- shard-bmg: NOTRUN -> [SKIP][6] ([Intel XE#3432])
[6]: https://intel-gfx-ci.01.org/tree/intel-xe/IGTPW_15435/shard-bmg-10/igt@kms_ccs@crc-primary-suspend-y-tiled-gen12-mc-ccs.html
* igt@kms_content_protection@legacy-hdcp14@pipe-a-dp-2:
- shard-bmg: NOTRUN -> [FAIL][7] ([Intel XE#1178] / [Intel XE#3304] / [Intel XE#7374]) +1 other test fail
[7]: https://intel-gfx-ci.01.org/tree/intel-xe/IGTPW_15435/shard-bmg-9/igt@kms_content_protection@legacy-hdcp14@pipe-a-dp-2.html
* igt@kms_cursor_crc@cursor-onscreen-512x512:
- shard-bmg: NOTRUN -> [SKIP][8] ([Intel XE#2321] / [Intel XE#7355])
[8]: https://intel-gfx-ci.01.org/tree/intel-xe/IGTPW_15435/shard-bmg-3/igt@kms_cursor_crc@cursor-onscreen-512x512.html
* igt@kms_dsc@dsc-with-output-formats-with-bpc-ultrajoiner:
- shard-bmg: NOTRUN -> [SKIP][9] ([Intel XE#8265]) +1 other test skip
[9]: https://intel-gfx-ci.01.org/tree/intel-xe/IGTPW_15435/shard-bmg-8/igt@kms_dsc@dsc-with-output-formats-with-bpc-ultrajoiner.html
* igt@kms_flip@flip-vs-expired-vblank-interruptible@b-edp1:
- shard-lnl: [PASS][10] -> [FAIL][11] ([Intel XE#301])
[10]: https://intel-gfx-ci.01.org/tree/intel-xe/IGT_8981/shard-lnl-2/igt@kms_flip@flip-vs-expired-vblank-interruptible@b-edp1.html
[11]: https://intel-gfx-ci.01.org/tree/intel-xe/IGTPW_15435/shard-lnl-4/igt@kms_flip@flip-vs-expired-vblank-interruptible@b-edp1.html
* igt@kms_flip@wf_vblank-ts-check-interruptible@a-edp1:
- shard-lnl: [PASS][12] -> [FAIL][13] ([Intel XE#3098]) +1 other test fail
[12]: https://intel-gfx-ci.01.org/tree/intel-xe/IGT_8981/shard-lnl-4/igt@kms_flip@wf_vblank-ts-check-interruptible@a-edp1.html
[13]: https://intel-gfx-ci.01.org/tree/intel-xe/IGTPW_15435/shard-lnl-1/igt@kms_flip@wf_vblank-ts-check-interruptible@a-edp1.html
* igt@kms_frontbuffer_tracking@drrshdr-1p-primscrn-spr-indfb-draw-blt:
- shard-bmg: NOTRUN -> [SKIP][14] ([Intel XE#2311]) +4 other tests skip
[14]: https://intel-gfx-ci.01.org/tree/intel-xe/IGTPW_15435/shard-bmg-6/igt@kms_frontbuffer_tracking@drrshdr-1p-primscrn-spr-indfb-draw-blt.html
* igt@kms_frontbuffer_tracking@drrshdr-argb161616f-draw-blt:
- shard-bmg: NOTRUN -> [SKIP][15] ([Intel XE#7061])
[15]: https://intel-gfx-ci.01.org/tree/intel-xe/IGTPW_15435/shard-bmg-8/igt@kms_frontbuffer_tracking@drrshdr-argb161616f-draw-blt.html
* igt@kms_frontbuffer_tracking@fbc-1p-offscreen-pri-indfb-draw-render:
- shard-bmg: NOTRUN -> [SKIP][16] ([Intel XE#4141]) +1 other test skip
[16]: https://intel-gfx-ci.01.org/tree/intel-xe/IGTPW_15435/shard-bmg-10/igt@kms_frontbuffer_tracking@fbc-1p-offscreen-pri-indfb-draw-render.html
* igt@kms_frontbuffer_tracking@psr-1p-rte:
- shard-bmg: NOTRUN -> [SKIP][17] ([Intel XE#2313]) +7 other tests skip
[17]: https://intel-gfx-ci.01.org/tree/intel-xe/IGTPW_15435/shard-bmg-6/igt@kms_frontbuffer_tracking@psr-1p-rte.html
* igt@kms_frontbuffer_tracking@psr-argb161616f-draw-mmap-wc:
- shard-bmg: NOTRUN -> [SKIP][18] ([Intel XE#7061] / [Intel XE#7356]) +2 other tests skip
[18]: https://intel-gfx-ci.01.org/tree/intel-xe/IGTPW_15435/shard-bmg-7/igt@kms_frontbuffer_tracking@psr-argb161616f-draw-mmap-wc.html
* igt@kms_hdmi_inject@inject-audio:
- shard-bmg: [PASS][19] -> [SKIP][20] ([Intel XE#7308])
[19]: https://intel-gfx-ci.01.org/tree/intel-xe/IGT_8981/shard-bmg-2/igt@kms_hdmi_inject@inject-audio.html
[20]: https://intel-gfx-ci.01.org/tree/intel-xe/IGTPW_15435/shard-bmg-2/igt@kms_hdmi_inject@inject-audio.html
* igt@kms_pm_backlight@fade-with-suspend:
- shard-bmg: NOTRUN -> [SKIP][21] ([Intel XE#7376] / [Intel XE#7760] / [Intel XE#870])
[21]: https://intel-gfx-ci.01.org/tree/intel-xe/IGTPW_15435/shard-bmg-2/igt@kms_pm_backlight@fade-with-suspend.html
* igt@kms_psr2_sf@psr2-primary-plane-update-sf-dmg-area:
- shard-bmg: NOTRUN -> [SKIP][22] ([Intel XE#1489])
[22]: https://intel-gfx-ci.01.org/tree/intel-xe/IGTPW_15435/shard-bmg-7/igt@kms_psr2_sf@psr2-primary-plane-update-sf-dmg-area.html
* igt@kms_psr@fbc-psr2-cursor-plane-move:
- shard-bmg: NOTRUN -> [SKIP][23] ([Intel XE#2234] / [Intel XE#2850]) +1 other test skip
[23]: https://intel-gfx-ci.01.org/tree/intel-xe/IGTPW_15435/shard-bmg-6/igt@kms_psr@fbc-psr2-cursor-plane-move.html
* igt@kms_vrr@seamless-rr-switch-virtual@pipe-a-edp-1:
- shard-lnl: [PASS][24] -> [FAIL][25] ([Intel XE#2142]) +1 other test fail
[24]: https://intel-gfx-ci.01.org/tree/intel-xe/IGT_8981/shard-lnl-3/igt@kms_vrr@seamless-rr-switch-virtual@pipe-a-edp-1.html
[25]: https://intel-gfx-ci.01.org/tree/intel-xe/IGTPW_15435/shard-lnl-7/igt@kms_vrr@seamless-rr-switch-virtual@pipe-a-edp-1.html
* igt@xe_compute@ccs-mode-compute-kernel:
- shard-bmg: NOTRUN -> [SKIP][26] ([Intel XE#6599])
[26]: https://intel-gfx-ci.01.org/tree/intel-xe/IGTPW_15435/shard-bmg-3/igt@xe_compute@ccs-mode-compute-kernel.html
* igt@xe_eudebug@basic-vm-bind-metadata-discovery:
- shard-bmg: NOTRUN -> [SKIP][27] ([Intel XE#7636]) +2 other tests skip
[27]: https://intel-gfx-ci.01.org/tree/intel-xe/IGTPW_15435/shard-bmg-7/igt@xe_eudebug@basic-vm-bind-metadata-discovery.html
* igt@xe_exec_basic@multigpu-once-userptr-invalidate-race:
- shard-bmg: NOTRUN -> [SKIP][28] ([Intel XE#2322] / [Intel XE#7372])
[28]: https://intel-gfx-ci.01.org/tree/intel-xe/IGTPW_15435/shard-bmg-7/igt@xe_exec_basic@multigpu-once-userptr-invalidate-race.html
* igt@xe_exec_fault_mode@twice-multi-queue-invalid-userptr-fault:
- shard-bmg: NOTRUN -> [SKIP][29] ([Intel XE#8374]) +1 other test skip
[29]: https://intel-gfx-ci.01.org/tree/intel-xe/IGTPW_15435/shard-bmg-8/igt@xe_exec_fault_mode@twice-multi-queue-invalid-userptr-fault.html
* igt@xe_exec_multi_queue@many-execs-dyn-priority:
- shard-bmg: NOTRUN -> [SKIP][30] ([Intel XE#8364]) +2 other tests skip
[30]: https://intel-gfx-ci.01.org/tree/intel-xe/IGTPW_15435/shard-bmg-7/igt@xe_exec_multi_queue@many-execs-dyn-priority.html
* igt@xe_exec_system_allocator@twice-malloc-bo-unmap:
- shard-lnl: [PASS][31] -> [ABORT][32] ([Intel XE#8007])
[31]: https://intel-gfx-ci.01.org/tree/intel-xe/IGT_8981/shard-lnl-6/igt@xe_exec_system_allocator@twice-malloc-bo-unmap.html
[32]: https://intel-gfx-ci.01.org/tree/intel-xe/IGTPW_15435/shard-lnl-8/igt@xe_exec_system_allocator@twice-malloc-bo-unmap.html
* igt@xe_exec_threads@threads-multi-queue-hang-fd-userptr-invalidate-race:
- shard-bmg: NOTRUN -> [SKIP][33] ([Intel XE#8378]) +3 other tests skip
[33]: https://intel-gfx-ci.01.org/tree/intel-xe/IGTPW_15435/shard-bmg-3/igt@xe_exec_threads@threads-multi-queue-hang-fd-userptr-invalidate-race.html
* igt@xe_page_reclaim@prl-invalidate-full:
- shard-bmg: NOTRUN -> [SKIP][34] ([Intel XE#7793])
[34]: https://intel-gfx-ci.01.org/tree/intel-xe/IGTPW_15435/shard-bmg-4/igt@xe_page_reclaim@prl-invalidate-full.html
* igt@xe_query@multigpu-query-invalid-cs-cycles:
- shard-bmg: NOTRUN -> [SKIP][35] ([Intel XE#944])
[35]: https://intel-gfx-ci.01.org/tree/intel-xe/IGTPW_15435/shard-bmg-1/igt@xe_query@multigpu-query-invalid-cs-cycles.html
* igt@xe_sriov_vram@vf-access-after-resize-up:
- shard-bmg: [PASS][36] -> [FAIL][37] ([Intel XE#7992])
[36]: https://intel-gfx-ci.01.org/tree/intel-xe/IGT_8981/shard-bmg-5/igt@xe_sriov_vram@vf-access-after-resize-up.html
[37]: https://intel-gfx-ci.01.org/tree/intel-xe/IGTPW_15435/shard-bmg-2/igt@xe_sriov_vram@vf-access-after-resize-up.html
#### Possible fixes ####
* igt@kms_async_flips@alternate-sync-async-flip:
- shard-bmg: [FAIL][38] ([Intel XE#3718] / [Intel XE#6078]) -> [PASS][39]
[38]: https://intel-gfx-ci.01.org/tree/intel-xe/IGT_8981/shard-bmg-8/igt@kms_async_flips@alternate-sync-async-flip.html
[39]: https://intel-gfx-ci.01.org/tree/intel-xe/IGTPW_15435/shard-bmg-2/igt@kms_async_flips@alternate-sync-async-flip.html
* igt@kms_async_flips@alternate-sync-async-flip@pipe-a-dp-2:
- shard-bmg: [FAIL][40] ([Intel XE#6078]) -> [PASS][41]
[40]: https://intel-gfx-ci.01.org/tree/intel-xe/IGT_8981/shard-bmg-8/igt@kms_async_flips@alternate-sync-async-flip@pipe-a-dp-2.html
[41]: https://intel-gfx-ci.01.org/tree/intel-xe/IGTPW_15435/shard-bmg-2/igt@kms_async_flips@alternate-sync-async-flip@pipe-a-dp-2.html
* igt@kms_flip@flip-vs-expired-vblank@b-edp1:
- shard-lnl: [FAIL][42] ([Intel XE#301]) -> [PASS][43] +1 other test pass
[42]: https://intel-gfx-ci.01.org/tree/intel-xe/IGT_8981/shard-lnl-8/igt@kms_flip@flip-vs-expired-vblank@b-edp1.html
[43]: https://intel-gfx-ci.01.org/tree/intel-xe/IGTPW_15435/shard-lnl-4/igt@kms_flip@flip-vs-expired-vblank@b-edp1.html
* igt@xe_sriov_flr@flr-basic@numvfs-1:
- shard-bmg: [FAIL][44] ([Intel XE#7992]) -> [PASS][45] +1 other test pass
[44]: https://intel-gfx-ci.01.org/tree/intel-xe/IGT_8981/shard-bmg-3/igt@xe_sriov_flr@flr-basic@numvfs-1.html
[45]: https://intel-gfx-ci.01.org/tree/intel-xe/IGTPW_15435/shard-bmg-1/igt@xe_sriov_flr@flr-basic@numvfs-1.html
* igt@xe_sriov_flr@flr-each-isolation:
- shard-bmg: [FAIL][46] ([Intel XE#6569]) -> [PASS][47]
[46]: https://intel-gfx-ci.01.org/tree/intel-xe/IGT_8981/shard-bmg-8/igt@xe_sriov_flr@flr-each-isolation.html
[47]: https://intel-gfx-ci.01.org/tree/intel-xe/IGTPW_15435/shard-bmg-10/igt@xe_sriov_flr@flr-each-isolation.html
#### Warnings ####
* igt@kms_tiled_display@basic-test-pattern:
- shard-bmg: [FAIL][48] ([Intel XE#1729] / [Intel XE#7424]) -> [SKIP][49] ([Intel XE#2426] / [Intel XE#5848])
[48]: https://intel-gfx-ci.01.org/tree/intel-xe/IGT_8981/shard-bmg-3/igt@kms_tiled_display@basic-test-pattern.html
[49]: https://intel-gfx-ci.01.org/tree/intel-xe/IGTPW_15435/shard-bmg-8/igt@kms_tiled_display@basic-test-pattern.html
{name}: This element is suppressed. This means it is ignored when computing
the status of the difference (SUCCESS, WARNING, or FAILURE).
[Intel XE#1124]: https://gitlab.freedesktop.org/drm/xe/kernel/issues/1124
[Intel XE#1178]: https://gitlab.freedesktop.org/drm/xe/kernel/issues/1178
[Intel XE#1489]: https://gitlab.freedesktop.org/drm/xe/kernel/issues/1489
[Intel XE#1729]: https://gitlab.freedesktop.org/drm/xe/kernel/issues/1729
[Intel XE#2142]: https://gitlab.freedesktop.org/drm/xe/kernel/issues/2142
[Intel XE#2234]: https://gitlab.freedesktop.org/drm/xe/kernel/issues/2234
[Intel XE#2311]: https://gitlab.freedesktop.org/drm/xe/kernel/issues/2311
[Intel XE#2313]: https://gitlab.freedesktop.org/drm/xe/kernel/issues/2313
[Intel XE#2321]: https://gitlab.freedesktop.org/drm/xe/kernel/issues/2321
[Intel XE#2322]: https://gitlab.freedesktop.org/drm/xe/kernel/issues/2322
[Intel XE#2426]: https://gitlab.freedesktop.org/drm/xe/kernel/issues/2426
[Intel XE#2850]: https://gitlab.freedesktop.org/drm/xe/kernel/issues/2850
[Intel XE#2887]: https://gitlab.freedesktop.org/drm/xe/kernel/issues/2887
[Intel XE#301]: https://gitlab.freedesktop.org/drm/xe/kernel/issues/301
[Intel XE#3098]: https://gitlab.freedesktop.org/drm/xe/kernel/issues/3098
[Intel XE#3304]: https://gitlab.freedesktop.org/drm/xe/kernel/issues/3304
[Intel XE#3432]: https://gitlab.freedesktop.org/drm/xe/kernel/issues/3432
[Intel XE#367]: https://gitlab.freedesktop.org/drm/xe/kernel/issues/367
[Intel XE#3718]: https://gitlab.freedesktop.org/drm/xe/kernel/issues/3718
[Intel XE#4141]: https://gitlab.freedesktop.org/drm/xe/kernel/issues/4141
[Intel XE#5848]: https://gitlab.freedesktop.org/drm/xe/kernel/issues/5848
[Intel XE#6078]: https://gitlab.freedesktop.org/drm/xe/kernel/issues/6078
[Intel XE#6569]: https://gitlab.freedesktop.org/drm/xe/kernel/issues/6569
[Intel XE#6599]: https://gitlab.freedesktop.org/drm/xe/kernel/issues/6599
[Intel XE#7061]: https://gitlab.freedesktop.org/drm/xe/kernel/issues/7061
[Intel XE#7308]: https://gitlab.freedesktop.org/drm/xe/kernel/issues/7308
[Intel XE#7355]: https://gitlab.freedesktop.org/drm/xe/kernel/issues/7355
[Intel XE#7356]: https://gitlab.freedesktop.org/drm/xe/kernel/issues/7356
[Intel XE#7372]: https://gitlab.freedesktop.org/drm/xe/kernel/issues/7372
[Intel XE#7374]: https://gitlab.freedesktop.org/drm/xe/kernel/issues/7374
[Intel XE#7376]: https://gitlab.freedesktop.org/drm/xe/kernel/issues/7376
[Intel XE#7424]: https://gitlab.freedesktop.org/drm/xe/kernel/issues/7424
[Intel XE#7636]: https://gitlab.freedesktop.org/drm/xe/kernel/issues/7636
[Intel XE#7760]: https://gitlab.freedesktop.org/drm/xe/kernel/issues/7760
[Intel XE#7793]: https://gitlab.freedesktop.org/drm/xe/kernel/issues/7793
[Intel XE#7992]: https://gitlab.freedesktop.org/drm/xe/kernel/issues/7992
[Intel XE#8007]: https://gitlab.freedesktop.org/drm/xe/kernel/issues/8007
[Intel XE#8265]: https://gitlab.freedesktop.org/drm/xe/kernel/issues/8265
[Intel XE#8364]: https://gitlab.freedesktop.org/drm/xe/kernel/issues/8364
[Intel XE#8374]: https://gitlab.freedesktop.org/drm/xe/kernel/issues/8374
[Intel XE#8378]: https://gitlab.freedesktop.org/drm/xe/kernel/issues/8378
[Intel XE#870]: https://gitlab.freedesktop.org/drm/xe/kernel/issues/870
[Intel XE#944]: https://gitlab.freedesktop.org/drm/xe/kernel/issues/944
Build changes
-------------
* IGT: IGT_8981 -> IGTPW_15435
* Linux: xe-5290-60326b17f877e12846167bf8ef83680b9875218a -> xe-5291-e2a6e04d045a56c6dc61e1eb9e2a6d7cf86512cd
IGTPW_15435: 15435
IGT_8981: 28416da6681a1afa167bdd73cdc934cb36d13133 @ https://gitlab.freedesktop.org/drm/igt-gpu-tools.git
xe-5290-60326b17f877e12846167bf8ef83680b9875218a: 60326b17f877e12846167bf8ef83680b9875218a
xe-5291-e2a6e04d045a56c6dc61e1eb9e2a6d7cf86512cd: e2a6e04d045a56c6dc61e1eb9e2a6d7cf86512cd
== Logs ==
For more details see: https://intel-gfx-ci.01.org/tree/intel-xe/IGTPW_15435/index.html
[-- Attachment #2: Type: text/html, Size: 18235 bytes --]
^ permalink raw reply [flat|nested] 13+ messages in thread